@@ -12,10 +12,6 @@ from .prefetch_generator import PrefetchGenerator
 from ..utils import is_available
 
 import numpy as np
-if is_available("tensorflow"):
-    import tensorflow as tf
-if is_available("torch"):
-    import torch
 
 
 logger = logging.getLogger(__name__)
@@ -109,7 +105,6 @@ class Dataset:
     def __iter__(self):
         return iter(self._data)
 
-
 class DataLoader:
     def __init__(self, dataset: Dataset, shuffle: bool = False, batch_size: int = 1, collate_fn: Optional[Callable] = None, prefetch_factor: int = 1, num_workers: int = 1, format: Optional[str] = None, padding_value: int = 0, **kwargs) -> None:
         self.dataset = dataset
@@ -118,7 +113,13 @@ class DataLoader:
         self._collate_fn = collate_fn
         self._prefetch_factor = prefetch_factor
         self._num_workers = num_workers
-        self._format = format if format in {"tf", "torch"} else "numpy"
+        self._format = format if format in {"tf", "tensorflow", "torch", "pytorch"} else "numpy"
+        if self._format in {"tf", "tensorflow"}:
+            if is_available("tensorflow"):
+                import tensorflow as tf
+        elif self._format in {"torch", "pytorch"}:
+            if is_available("torch"):
+                import torch
         self._padding_value = padding_value
         self._gen = PrefetchGenerator(self.dataset._data, num_prefetch=self._prefetch_factor*self._batch_size, num_workers=self._num_workers, shuffle=self._shuffle, processing_func=self._collate_fn, name="DataLoader")
 
@@ -146,12 +147,14 @@ class DataLoader:
             raise ModuleNotFoundError("numpy")
         if self._format == "tf":
             if is_available("tensorflow"):
+                import tensorflow as tf
                 for i in range(len(datas)):
                     datas[i] = tf.convert_to_tensor(datas[i])
             else:
                 raise ModuleNotFoundError("tensorflow")
         elif self._format == "torch":
             if is_available("torch"):
+                import torch
                 for i in range(len(datas)):
                     datas[i] = torch.tensor(datas[i])
             else:
